@@ -51,8 +51,13 @@ setMethodS3("insert", "default", function(x, ats, values=NA, ...) {
   if (!is.vector(values))
     throw("Argument 'values' is not a vector: ", class(values));
 
-  if (!is.list(values))
-    values <- list(values);
+  if (!is.list(values)) {
+    if (length(ats) == 1) {
+      values <- list(values);
+    } else {
+      values <- as.list(values);
+    }
+  }
 
   if (length(ats) != length(values)) 
     throw("Argument 'ats' and argument 'values' has different lengths: ", 
@@ -122,6 +127,9 @@ setMethodS3("insert", "default", function(x, ats, values=NA, ...) {
 
 ############################################################################
 # HISTORY:
+# 2008-02-21
+# o BUG FIX: When 'values' was a non-list its values were placed in a 
+#   single-element list.  Should have been as.list().
 # 2005-06-12
 # o Updated a lot! Wrote a rather large example.
 # 2005-02-20
